{ pkgs, lib, config, namespace, ... }:
let
  inherit (lib.${namespace}) enabled;
in
{
  reichard = {
    user = {
      enable = true;
      inherit (config.snowfallorg.user) name;
    };

    services = {
      ssh-agent = enabled;
    };

    programs = {
      graphical = {
        ghostty = enabled;
      };

      terminal = {
        btop = enabled;
        direnv = enabled;
        git = enabled;
        k9s = enabled;
        nvim = enabled;
        aws = enabled;
      };
    };
  };

  # Global Packages
  programs.jq = enabled;
  programs.pandoc = enabled;
  home.packages = with pkgs; [
    android-tools
    imagemagick
    mosh
    python311
    texliveSmall # Pandoc PDF Dep
    google-cloud-sdk
    tldr
  ];

  # SQLite Configuration
  home.file.".sqliterc".text = ''
    .headers on
    .mode column
  '';

  home.stateVersion = "24.11";
}
